ProtocolEx.MissingAsInArgs exception (protocol_ex v0.5.1)
Copy MarkdownThis is raised when an as name is specified but is missing from a function argument list.
Summary
Functions
Callback implementation for Exception.message/1.
Functions
Callback implementation for Exception.message/1.